This is a simple alternative to django-ajax-selects.

Resources
---------

Documentation graciously hosted by RTFD:
http://django-autocomplete-light.rtfd.org

Continuous integration graciously hosted by Travis:
http://travis-ci.org/yourlabs/django-autocomplete-light

Git graciously hosted by GitHub:
https://github.com/yourlabs/django-autocomplete-light/

Demo
----

See test_project/README
